@@ -1,5 +1,5 @@
 #' @title 
-#' Create trans_classifier object for machine-learning-based model prediction.
+#' Create \code{trans_classifier} object for machine-learning-based model prediction.
 #'
 #' @description
 #' This class is a wrapper for methods of machine-learning-based classification or regression models, including data pre-processing, feature selection, 
@@ -11,20 +11,21 @@
 trans_classifier <- R6::R6Class(classname = "trans_classifier",
 	public = list(
 		#' @description
-		#' Create the trans_classifier object.
+		#' Create a trans_classifier object.
 		#' 
-		#' @param dataset the object of \code{\link{microtable}} Class.
-		#' @param x.predictors default "Genus"; character string or data.frame; a character string represents selecting the corresponding data from microtable$taxa_abund; 
-		#'   data.frame represents other customized input. See the following available options:
+		#' @param dataset an object of \code{\link{microtable}} class.
+		#' @param x.predictors default "Genus"; character string or data.frame; a character string represents selecting the corresponding data from \code{microtable$taxa_abund}; 
+		#'   data.frame denotes other customized input. See the following available options:
 		#'   \describe{
-		#'     \item{\strong{'Genus'}}{use Genus level table in microtable$taxa_abund, or other specific taxonomic rank, e.g. 'Phylum'}
-		#'     \item{\strong{'all'}}{use all the taxa stored in microtable$taxa_abund}
-		#'     \item{\strong{other input}}{must be a data.frame; It should have the same format with the data.frame in microtable$taxa_abund, i.e. rows are features; 
-		#'       cols are samples with same names in sample_table}
+		#'     \item{\strong{'Genus'}}{use Genus level table in \code{microtable$taxa_abund}, or other specific taxonomic rank, e.g., 'Phylum'.
+		#'        If an input level (e.g., ASV) is not found in the names of taxa_abund list, the function will use \code{otu_table} to calculate relative abundance of features.}
+		#'     \item{\strong{'all'}}{use all the levels stored in \code{microtable$taxa_abund}.}
+		#'     \item{\strong{other input}}{must be a data.frame object. It should have the same format with the tables in microtable$taxa_abund, i.e. rows are features; 
+		#'       columns are samples with same names in sample_table.}
 		#'   }
 		#' @param y.response default NULL; the response variable in \code{sample_table} of input \code{microtable} object.
 		#' @param n.cores default 1; the CPU thread used.
-		#' @return data_feature and data_response in the object.
+		#' @return \code{data_feature} and \code{data_response} stored in the object.
 		#' @examples
 		#' \donttest{
 		#' data(dataset)
@@ -83,8 +84,9 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 					abund_table <- do.call(rbind, unname(dataset$taxa_abund))
 				}else{
 					if(! x.predictors %in% names(dataset$taxa_abund)){
-						message("x.predictors is not found in the taxa_abund list. Use the features in otu_table ...")
+						message("x.predictors: ", x.predictors, " is not found in the names of taxa_abund list. Use the features in otu_table ...")
 						dataset$add_rownames2taxonomy(use_name = x.predictors)
+						message("Calculate relative abundance of features ...")
 						suppressMessages(dataset$cal_abund())
 					}
 					abund_table <- dataset$taxa_abund[[x.predictors]]
@@ -95,13 +97,15 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 					stop("Provided x.predictors is neither character nor data.frame !")
 				}
 				abund_table <- x.predictors
-				# maybe more checking later
+				if(! any(colnames(abund_table) %in% rownames(sampleinfo))){
+					stop("Please make sure the column names in provided x.predictors are sample names!")
+				}
 			}
 			# remove meaningless things
 			abund_table %<>% {
 				.[!grepl("__$|uncultured$|Incertae..edis$|_sp$", rownames(.), ignore.case = TRUE), ]
 			}
-			DataX <- abund_table %>% t() %>% as.data.frame()			
+			DataX <- abund_table %>% t() %>% as.data.frame(check.names = FALSE)
 			message("Total feature numbers: ", ncol(DataX))
 			
 			if(n.cores > 1){
@@ -118,9 +122,10 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 		#' 	 See \href{https://topepo.github.io/caret/pre-processing.html}{https://topepo.github.io/caret/pre-processing.html} for more details.
 		#' 
 		#' @param ... parameters pass to \code{preProcess} function of caret package.
-		#' @return converted data_feature in the object.
+		#' @return preprocessed \code{data_feature} in the object.
 		#' @examples
 		#' \dontrun{
+		#' # "nzv" removes near zero variance predictors
 		#' t1$cal_preProcess(method = c("center", "scale", "nzv"))
 		#' }
 		cal_preProcess = function(...){
@@ -134,11 +139,11 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 		#' Perform feature selection.
 		#' 	 See \href{https://topepo.github.io/caret/feature-selection-overview.html}{https://topepo.github.io/caret/feature-selection-overview.html} for more details.
 		#' 
-		#' @param boruta.maxRuns default 300; maximal number of importance source runs; passed to the maxRuns parameter in Boruta function of Boruta package.
-		#' @param boruta.pValue default 0.01; p value passed to the pValue parameter in Boruta function of Boruta package.
+		#' @param boruta.maxRuns default 300; maximal number of importance source runs; passed to the \code{maxRuns} parameter in \code{Boruta} function of Boruta package.
+		#' @param boruta.pValue default 0.01; p value passed to the pValue parameter in \code{Boruta} function of Boruta package.
 		#' @param boruta.repetitions default 4; repetition runs for the feature selection.
 		#' @param ... parameters pass to \code{Boruta} function of Boruta package.
-		#' @return optimized data_feature in the object.
+		#' @return optimized \code{data_feature} in the object.
 		#' @examples
 		#' \dontrun{
 		#' t1$cal_feature_sel(boruta.maxRuns = 300, boruta.pValue = 0.01)
@@ -182,7 +187,7 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 		#' Split data for training and testing.
 		#' 
 		#' @param prop.train default 3/4; the ratio of the data used for the training.
-		#' @return data_train and data_test in the object.
+		#' @return \code{data_train} and \code{data_test} in the object.
 		#' @examples
 		#' \dontrun{
 		#' t1$cal_split(prop.train = 3/4)
@@ -194,9 +199,9 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 			if(self$type == "Classification"){
 				data_response %<>% factor
 			}
-			DataX <- self$data_feature
+			data_feature <- self$data_feature
 
-			data_all <- data.frame(Response = data_response, DataX)
+			data_all <- data.frame(Response = data_response, data_feature, check.names = FALSE)
 			SplitData <- rsample::initial_split(data_all, prop = prop.train, strata = "Response")
 			train_data <- rsample::training(SplitData)
 			test_data <- rsample::testing(SplitData)
@@ -208,15 +213,15 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 			message("Training and testing data are stored in object$data_train and object$data_test respectively ...")
 		},
 		#' @description
-		#' Control parameters for the following training. See trainControl function of caret package for details.
+		#' Control parameters for the following training. Please see \code{trainControl} function of caret package for details.
 		#' 
 		#' @param method default 'repeatedcv'; 'repeatedcv': Repeated k-Fold cross validation; 
 		#' 	 see method parameter in \code{trainControl} function of \code{caret} package for available options.
 		#' @param classProbs default TRUE; should class probabilities be computed for classification models?;
 		#' 	 see classProbs parameter in \code{caret::trainControl} function.
 		#' @param savePredictions default TRUE; see \code{savePredictions} parameter in \code{caret::trainControl} function.
-		#' @param ... parameters pass to trainControl function of caret package.
-		#' @return trainControl in the object.
+		#' @param ... parameters pass to \code{trainControl} function of caret package.
+		#' @return \code{trainControl} in the object.
 		#' @examples
 		#' \dontrun{
 		#' t1$set_trainControl(method = 'repeatedcv')
@@ -240,13 +245,16 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 			self$trainControl <- trainControl
 		},
 		#' @description
-		#' Run the model training.
+		#' Run the model training. Please see \href{https://topepo.github.io/caret/available-models.html}{https://topepo.github.io/caret/available-models.html} for available models.
 		#' 
-		#' @param method default "rf"; "rf": random forest; see method in caret::train function for other options.
-		#' @param max.mtry default 2; for method = "rf"; maximum mtry used for the tunegrid to do hyperparameter tuning to optimize the model.
-		#' @param max.ntree default 200; for method = "rf"; maximum number of trees used to optimize the model.
+		#' @param method default "rf"; "rf": random forest; see method in \code{train} function of caret package for other options.
+		#' 	  For method = "rf", the \code{tuneGrid} is set: \code{expand.grid(mtry = seq(from = 1, to = max.mtry))}
+		#' @param max.mtry default 2; for method = "rf"; maximum mtry used in the \code{tuneGrid} to do hyperparameter tuning to optimize the model.
+		#' @param ntree default 500; for method = "rf"; Number of trees to grow. 
+		#' 	  The default 500 is same with the \code{ntree} parameter in \code{randomForest} function in randomForest package.
+		#' 	  When it is a vector with more than one element, the function will try to optimize the model to select a best one, such as \code{c(100, 500, 1000)}.
 		#' @param ... parameters pass to \code{caret::train} function.
-		#' @return res_train in the object.
+		#' @return \code{res_train} in the object.
 		#' @examples
 		#' \dontrun{
 		#' # random forest
@@ -257,48 +265,55 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 		cal_train = function(
 			method = "rf",
 			max.mtry = 2,
-			max.ntree = 200,
+			ntree = 500,
 			...
 			){
 			train_data <- self$data_train
+			if(is.null(train_data)){
+				message("No training data is found! The reason is function cal_split is not performed! Use all the samples for the training ...")
+				train_data <- data.frame(Response = self$data_response, self$data_feature, check.names = FALSE)
+				if(self$type == "Classification"){
+					train_data$Response %<>% as.factor
+				}
+				self$data_train <- train_data
+			}
 			trControl <- self$trainControl
+			if(is.null(trControl)){
+				trControl <- caret::trainControl()
+			}
 			
 			###################### ----------------
 			if(method == "rf" & self$type == "Classification"){
 				# Optimization of RF parameters
 				message("Optimization of Random Forest parameters ...")
-
-				tunegrid <- expand.grid(.mtry=seq(from =1, to = max.mtry) )
-				modellist<- list()
-				
-				for (ntree in c(100, max.ntree)) {
-					fit <- caret::train(Response ~ ., data = train_data, method = method,
-									  tuneGrid = tunegrid, trControl = trControl, ntree = ntree, ...)
-					key <- toString(ntree)
-					modellist[[key]] <- fit
-				}
-				# compare results
-				results.tune1 <- caret::resamples(modellist)
-				res.tune1 <- summary(results.tune1)
-				res.tune1 <- as.data.frame(res.tune1$statistics$Accuracy)
-				#summary(results)
-
-				ntree <- as.numeric(rownames(res.tune1)[which(res.tune1$Mean == max(res.tune1$Mean))])[1]
-				#tunegrid <- expand.grid(.mtry=seq(from = 1, to=4, by = 0.5))
 				modellist <- list()
-
-				fit <- caret::train(Response ~ ., data = train_data, method = method, 
-					tuneGrid = tunegrid, 
-					trControl = trControl, ntree = ntree)
-
-				message("ntree used:", ntree)
+				# capture the parameters
+				all_parameters <- c(as.list(environment()), list(...))
+				
+				tuneGrid <- expand.grid(mtry = seq(from = 1, to = max.mtry))
+				
+				if(length(ntree) > 1){
+					for (test_ntree in ntree){
+						fit <- caret::train(Response ~ ., data = train_data, method = method, tuneGrid = tuneGrid, trControl = trControl, ntree = test_ntree, ...)
+						key <- toString(test_ntree)
+						modellist[[key]] <- fit
+					}
+					# compare results
+					results.tune1 <- caret::resamples(modellist)
+					res.tune1 <- summary(results.tune1)
+					res.tune1 <- as.data.frame(res.tune1$statistics$Accuracy)
+					ntree <- as.numeric(rownames(res.tune1)[which(res.tune1$Mean == max(res.tune1$Mean))])[1]
+					fit <- caret::train(Response ~ ., data = train_data, method = method, tuneGrid = tuneGrid, trControl = trControl, ntree = ntree, ...)
+					message("ntree used:", ntree)
+				}else{
+					fit <- caret::train(Response ~ ., data = train_data, method = method, tuneGrid = tuneGrid, trControl = trControl, ntree = ntree, ...)
+				}
 				message("best mtry:", fit$bestTune$mtry)
-
-				tunegrid <- expand.grid(.mtry=fit$bestTune$mtry)
-				res_train <- caret::train(x=train_data[,2:ncol(train_data)], y = train_data[,1], method = method, 
-										 tuneGrid = tunegrid, trControl = trControl, ntree = ntree, ...)
-
 				######################Optimization of RF parameters end				
+
+				tuneGrid <- expand.grid(.mtry=fit$bestTune$mtry)
+				res_train <- caret::train(Response ~ ., data = train_data, method = method, tuneGrid = tuneGrid, trControl = trControl, ntree = ntree, ...)
+				self$train_params <- list(mtry = fit$bestTune$mtry, ntree = ntree)
 			}else{
 				res_train <- caret::train(Response ~ ., data = train_data, method = method, trControl = trControl, ...)
 			}
@@ -308,48 +323,139 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 		},
 		#' @description
 		#' Get feature importance from the training model.
-		#' @param ... parameters pass to varImp function of caret package.
-		#' @return res_feature_imp in the object. One row for each predictor variable. The column(s) are different importance measures.
-		#'   For the method 'rf', it is MeanDecreaseGini (classification) or IncNodePurity (regression).
+		#' @param rf_feature_sig default FALSE; whether calculate feature significance in 'rf' model using \code{rfPermute} package; 
+		#'    only available for \code{method = "rf"} in \code{cal_train} function; 
+		#' @param ... parameters pass to \code{varImp} function of caret package. 
+		#'    If \code{rf_feature_sig} is TURE and \code{train_method} is "rf", the parameters will be passed to \code{rfPermute} function of rfPermute package.
+		#' @return \code{res_feature_imp} in the object. One row for each predictor variable. The column(s) are different importance measures.
+		#'   For the method 'rf', it is MeanDecreaseGini (classification) or IncNodePurity (regression) when \code{rf_feature_sig = FALSE}.
 		#' @examples
 		#' \dontrun{
 		#' t1$cal_feature_imp()
 		#' }
-		cal_feature_imp = function(...){
+		cal_feature_imp = function(rf_feature_sig = FALSE, ...){
 			if(is.null(self$res_train)){
 				stop("Please first run cal_train to train the model !")
 			}
-			res_feature_imp <- caret::varImp(self$res_train$finalModel, ...)
-			
+			if(self$train_method == "rf"){
+				if(rf_feature_sig){
+					train_data <- self$data_train
+					# replace feature names with simplified character
+					match_table <- data.frame(rawname = colnames(train_data)[2:ncol(train_data)], replacename = paste0("r", 1:(ncol(train_data) - 1)))
+					colnames(train_data)[2:ncol(train_data)] <- match_table$replacename
+					if(is.null(self$train_params)){
+						rfp_res <- rfPermute::rfPermute(Response ~ ., data = train_data, ...)
+					}else{
+						rfp_res <- rfPermute::rfPermute(Response ~ ., data = train_data, ntree = self$train_params[["ntree"]], mtry = self$train_params[["mtry"]], ...)
+					}
+					res_feature_imp <- rfPermute::importance(rfp_res, scale = TRUE) %>% as.data.frame(check.names = FALSE)
+					rownames(res_feature_imp) <- match_table[match(rownames(res_feature_imp), match_table[, 2]), 1]
+				}else{
+					res_feature_imp <- caret::varImp(self$res_train$finalModel, ...)
+				}
+			}else{
+				res_feature_imp <- caret::varImp(self$res_train$finalModel, ...)
+			}
 			self$res_feature_imp <- res_feature_imp
 			message('The feature importance is stored in object$res_feature_imp ...')
 		},
 		#' @description
 		#' Bar plot for feature importance.
+		#' @param rf_sig_show default NULL; "MeanDecreaseAccuracy" (Default) or "MeanDecreaseGini" for random forest classification;
+		#' 	  "\%IncMSE" (Default) or "IncNodePurity" for random forest regression;
+		#' 	  Only available when \code{rf_feature_sig = TRUE} in function \code{cal_feature_imp}, 
+		#' 	  which generate "MeanDecreaseGini" (and "MeanDecreaseAccuracy") or "\%IncMSE" (and "IncNodePurity") in the column names of \code{res_feature_imp};
+		#' 	  Function can also generate "Significance" according to the p value.
+		#' @param show_sig_group default FALSE; whether show the features with different significant groups;
+		#' 	  Only available when "Significance" is found in the data.
 		#' @param ... parameters pass to \code{plot_diff_bar} function of \code{trans_diff} package.
-		#' @return ggplot2 object.
+		#' @return \code{ggplot2} object.
 		#' @examples
 		#' \dontrun{
 		#' t1$plot_feature_imp(use_number = 1:20, coord_flip = FALSE)
 		#' }
-		plot_feature_imp = function(...){
+		plot_feature_imp = function(rf_sig_show = NULL, show_sig_group = FALSE, ...){
 			if(is.null(self$res_feature_imp)){
-				stop("Please first run cal_feature_imp !")
+				stop("Please first run function cal_feature_imp !")
+			}
+			tmp <- data.frame(Taxa = rownames(self$res_feature_imp), self$res_feature_imp, check.names = FALSE)
+			tmp$Taxa %<>% gsub("`", "", ., fixed = TRUE) %>% gsub("\\.(.__)", "\\|\\1", .)
+			if(! "Value" %in% colnames(tmp)){
+				if("Overall" %in% colnames(tmp)){
+					colnames(tmp)[colnames(tmp) == "Overall"] <- "Value"
+				}else{
+					if(any(c("MeanDecreaseAccuracy", "MeanDecreaseGini", "%IncMSE", "IncNodePurity") %in% colnames(tmp))){
+						if(is.null(rf_sig_show)){
+							if(self$type == "Classification"){
+								rf_sig_show = "MeanDecreaseAccuracy"
+							}else{
+								rf_sig_show = "%IncMSE"
+							}
+						}else{
+							if(self$type == "Classification"){
+								if(! rf_sig_show %in% c("MeanDecreaseAccuracy", "MeanDecreaseGini")){
+									stop("Provided rf_sig_show must be one of 'MeanDecreaseAccuracy' and 'MeanDecreaseGini'!")
+								}
+							}else{
+								if(! rf_sig_show %in% c("%IncMSE", "IncNodePurity")){
+									stop("Provided rf_sig_show must be one of '%IncMSE' and 'IncNodePurity'!")
+								}
+							}
+						}
+						colnames(tmp)[colnames(tmp) == rf_sig_show] <- "Value"
+						colnames(tmp)[colnames(tmp) == paste0(rf_sig_show, ".pval")] <- "pvalue"
+						tmp$Significance <- generate_p_siglabel(tmp$pvalue, nonsig = "ns")
+						tmp %<>% .[, c("Taxa", "Value", "pvalue", "Significance")]
+					}else{
+						if(is.numeric(tmp[, 2])){
+							colnames(tmp)[2] <- "Value"
+						}else{
+							stop("The res_feature_imp format can not be correctly recognized!")
+						}
+					}
+				}
+			}
+			if(show_sig_group){
+				if("Significance" %in% colnames(tmp)){
+					tmp$Group <- tmp$Significance %>% factor(., levels = c("***", "**", "*", "ns"))
+				}
 			}
-			tmp <- data.frame(Taxa = rownames(self$res_feature_imp), Value = self$res_feature_imp[, 1])
-			tmp$Taxa %<>% gsub("\\.(.__)", "\\|\\1", .)
 			
 			suppressMessages(trans_diff_tmp <- trans_diff$new(dataset = NULL))
 			trans_diff_tmp$res_diff <- tmp
 			trans_diff_tmp$method <- "rf"
-			trans_diff_tmp$plot_diff_bar(coord_flip = FALSE, ...)
+			g1 <- trans_diff_tmp$plot_diff_bar(...)
+			if(is.null(rf_sig_show)){
+				g1 <- g1 + ylab("Value")
+			}else{
+				g1 <- g1 + ylab(rf_sig_show)
+			}
+			g1
 		},
 		#' @description
 		#' Run the prediction.
 		#' 
-		#' @param positive_class default NULL; see positive parameter in confusionMatrix function of caret package;
+		#' @param positive_class default NULL; see positive parameter in \code{confusionMatrix} function of caret package;
 		#' If positive_class is NULL, use the first group in data as the positive class automatically.
-		#' @return res_predict, res_confusion_fit and res_confusion_stats stored in the object.
+		#' @return \code{res_predict}, \code{res_confusion_fit} and \code{res_confusion_stats} stored in the object.
+		#' 	  The \code{res_predict} is the predicted result for \code{data_test}.
+		#' 	  Several evaluation metrics in \code{res_confusion_fit} are defined as follows:
+		#' 	 \deqn{Accuracy = \frac{TP + TN}{TP + TN + FP + FN}}
+		#'   \deqn{Sensitivity = Recall = TPR = \frac{TP}{TP + FN}}
+		#'   \deqn{Specificity = TNR = 1 - FPR = \frac{TN}{TN + FP}}
+		#'   \deqn{Precision = \frac{TP}{TP + FP}}
+		#' 	 \deqn{Prevalence = \frac{TP + FN}{TP + TN + FP + FN}}
+		#' 	 \deqn{F1-Score = \frac{2 * Precision * Recall}{Precision + Recall}}
+		#' 	 \deqn{Kappa = \frac{Accuracy - Pe}{1 - Pe}}
+		#'   where TP is true positive; TN is ture negative; FP is false positive; and FN is false negative;
+		#'   FPR is False Positive Rate; TPR is True Positive Rate; TNR is True Negative Rate;
+		#'   Pe is the hypothetical probability of chance agreement on the classes for reference and prediction in the confusion matrix.
+		#'   Accuracy represents the ratio of correct predictions.
+		#'   Precision identifies how the model accurately predicted the positive classes.
+		#'   Recall (sensitivity) measures the ratio of actual positives that are correctly identified by the model.
+		#'   F1-score is the weighted average score of recall and precision. The value at 1 is the best performance and at 0 is the worst.
+		#'   Prevalence represents how often positive events occurred.
+		#'   Kappa identifies how well the model is predicting.
 		#' @examples
 		#' \dontrun{
 		#' t1$cal_predict()
@@ -362,6 +468,9 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 			}
 			fit.best <- self$res_train
 			test_data <- self$data_test
+			if(is.null(test_data)){
+				stop("No testing data is found! Please first run cal_split function!")
+			}
 
 			fit.best.predict <- predict(fit.best, test_data[, 2:ncol(test_data)])
 			self$res_predict <- fit.best.predict
@@ -393,11 +502,11 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 			}
 		},
 		#' @description
-		#' Plot the cross-tabulation of observed and predicted classes with associated statistics.
+		#' Plot the cross-tabulation of observed and predicted classes with associated statistics based on the results of function \code{cal_predict}.
 		#' 
 		#' @param plot_confusion default TRUE; whether plot the confusion matrix.
 		#' @param plot_statistics default TRUE; whether plot the statistics.
-		#' @return ggplot object.
+		#' @return \code{ggplot} object.
 		#' @examples
 		#' \dontrun{
 		#' t1$plot_confusionMatrix()
@@ -442,7 +551,8 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 		#' 
 		#' @param input default "pred"; 'pred' or 'train'; 'pred' represents using prediction results;
 		#'   'train' represents using training results.
-		#' @return a list res_ROC stored in the object.
+		#' @return a list \code{res_ROC} stored in the object. It has two tables: \code{res_roc} and \code{res_pr}. AUC: Area Under the ROC Curve.
+		#'   For the definition of metrics, please refer to the return part of function \code{cal_predict}.
 		#' @examples
 		#' \dontrun{
 		#' t1$cal_ROC()
@@ -503,8 +613,8 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 		#' @param color_values default RColorBrewer::brewer.pal(8, "Dark2"); colors used in the plot.
 		#' @param add_AUC default TRUE; whether add AUC in the legend.
 		#' @param plot_method default FALSE; If TRUE, show the method in the legend though only one method is found.
-		#' @param ... parameters pass to geom_path function of ggplot2 package.
-		#' @return ggplot2 object.
+		#' @param ... parameters pass to \code{geom_path} function of ggplot2 package.
+		#' @return \code{ggplot2} object.
 		#' @examples
 		#' \dontrun{
 		#' t1$plot_ROC(size = 1, alpha = 0.7)
@@ -567,33 +677,88 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 			p
 		},
 		#' @description
-		#' Use caretList function of caretEnsemble package to run multiple models. For the available models, please run \code{names(getModelInfo())}.
+		#' Use \code{caretList} function of caretEnsemble package to run multiple models. For the available models, please run \code{names(getModelInfo())}.
 		#' 
-		#' @param ... parameters pass to \code{caretList} function of caretEnsemble package.
-		#' @return res_caretList_models object.
+		#' @param ... parameters pass to \code{caretList} function of \code{caretEnsemble} package.
+		#' @return \code{res_caretList_models} in the object.
 		#' @examples
 		#' \dontrun{
 		#' t1$cal_caretList(methodList = c('rf', 'svmRadial'))
 		#' }
-		cal_caretList = function(
-			...
-			){
+		cal_caretList = function(...){
 			if(!require(caretEnsemble)){
 				stop("Please first install caretEnsemble package from CRAN!")
 			}
-			if(is.null(self$trainControl)){
-				stop("Please first run set_trainControl function!")
-			}
 			use_trainControl <- self$trainControl
 			train_data <- self$data_train
+			if(is.null(train_data)){
+				message("No training data is found! The reason is function cal_split is not performed! Use all the samples for the training ...")
+				train_data <- data.frame(Response = self$data_response, self$data_feature, check.names = FALSE)
+				if(self$type == "Classification"){
+					train_data$Response %<>% as.factor
+				}
+				self$data_train <- train_data
+			}
 			
 			models <- caretList(Response ~ ., data = train_data, trControl = use_trainControl, ...)
 			self$res_caretList_models <- models
 			message('Models are stored in object$res_caretList_models ...')
+		},
+		#' @description
+		#' Use \code{resamples} function of caret package to collect the metric values based on the \code{res_caretList_models} data.
+		#' 
+		#' @param ... parameters pass to \code{resamples} function of \code{caret} package.
+		#' @return \code{res_caretList_resamples} list and \code{res_caretList_resamples_reshaped} table in the object.
+		#' @examples
+		#' \dontrun{
+		#' t1$cal_caretList_resamples()
+		#' }
+		cal_caretList_resamples = function(...){
+			if(is.null(self$res_caretList_models)){
+				stop("Please first run cal_caretList function!")
+			}
+			res_caretList_models <- self$res_caretList_models
+			results <- caret::resamples(res_caretList_models, ...)
+			self$res_caretList_resamples <- results
+			message('Raw resamples results are stored in object$res_caretList_resamples ...')
+
+			all_data <- results$values
+			model_names <- colnames(all_data) %>% .[. != "Resample"] %>% gsub("~.*", "", .) %>% unique
+			metric_names <- colnames(all_data) %>% .[. != "Resample"] %>% gsub(".*~", "", .) %>% unique
+			reshaped_data <- lapply(model_names, function(x){
+				extract_value <- all_data[, paste0(x, "~", metric_names), drop = FALSE]
+				colnames(extract_value) <- metric_names
+				data.frame(Model = x, extract_value)
+			}) %>% do.call(rbind, .) %>% as.data.frame(check.names = FALSE)
+			reshaped_data <- reshape2::melt(reshaped_data, id.vars = "Model")
+			colnames(reshaped_data) <- c("Model", "Metric", "Value")
+			self$res_caretList_resamples_reshaped <- reshaped_data
+			message('Reshaped metric values are stored in object$res_caretList_resamples_reshaped ...')
+		},
+		#' @description
+		#' Visualize the metric values based on the \code{res_caretList_resamples_reshaped} data.
+		#' 
+		#' @param color_values default \code{RColorBrewer::brewer.pal}(8, "Dark2"); colors palette for the box.
+		#' @param ... parameters pass to \code{geom_boxplot} function of \code{ggplot2} package.
+		#' @return ggplot object.
+		#' @examples
+		#' \dontrun{
+		#' t1$plot_caretList_resamples()
+		#' }
+		plot_caretList_resamples = function(color_values = RColorBrewer::brewer.pal(8, "Dark2"), ...){
+			if(is.null(self$res_caretList_resamples_reshaped)){
+				stop("Please first run cal_caretList_resamples function!")
+			}
+			reshaped_data <- self$res_caretList_resamples_reshaped
+			
+			p <- ggplot(reshaped_data, aes(x = Model, y = Value, colour = Model)) + 
+				geom_boxplot(...) +
+				scale_color_manual(values = color_values) +
+				facet_grid(Metric ~ ., drop = TRUE, scale = "free", space = "fixed")
+			p
 		}
 	),
 	lock_class = FALSE,
 	lock_objects = FALSE
 )
 
-
